@@ -1,4 +1,7 @@
+#![forbid(unsafe_code)]
+
 pub use futures;
+mod async_runtime;
 pub mod collect_and_apply;
 pub mod combinations;
 pub mod keep_first_n;
